@@ -65,8 +65,8 @@ static org::kde::KSlaveLauncher *klauncher()
 {
     KDEInitInterface::ensureKdeinitRunning();
     if (!s_kslaveLauncher.hasLocalData()) {
-        org::kde::KSlaveLauncher *launcher = new org::kde::KSlaveLauncher(QString::fromLatin1("org.kde.klauncher5"),
-                QString::fromLatin1("/KLauncher"),
+        org::kde::KSlaveLauncher *launcher = new org::kde::KSlaveLauncher(QStringLiteral("org.kde.klauncher5"),
+                QStringLiteral("/KLauncher"),
                 QDBusConnection::sessionBus());
         s_kslaveLauncher.setLocalData(launcher);
         return launcher;
@@ -87,6 +87,11 @@ static bool forkSlaves()
     if (bForkSlaves.load() == -1) {
         bool fork = qEnvironmentVariableIsSet("KDE_FORK_SLAVES");
 
+        // no dbus? => fork slaves as we can't talk to klauncher
+        if (!fork) {
+            fork = !QDBusConnection::sessionBus().interface();
+        }
+
 #ifdef Q_OS_UNIX
         // fallback: if there's an klauncher process owned by a different user: still fork
         if (!fork) {
@@ -434,7 +439,7 @@ void Slave::resetHost()
 {
     Q_D(Slave);
     d->sslMetaData.clear();
-    d->m_host = "<reset>";
+    d->m_host = QStringLiteral("<reset>");
 }
 
 void Slave::setConfig(const MetaData &config)
@@ -450,11 +455,17 @@ Slave *Slave::createSlave(const QString &protocol, const QUrl &url, int &error,
 {
     //qDebug() << "createSlave" << protocol << "for" << url;
     // Firstly take into account all special slaves
-    if (protocol == "data") {
+    if (protocol == QLatin1String("data")) {
         return new DataProtocol();
     }
     Slave *slave = new Slave(protocol);
     QUrl slaveAddress = slave->d_func()->slaveconnserver->address();
+    if (slaveAddress.isEmpty()) {
+        error_text = i18n("Can not create socket for launching io-slave for protocol '%1'.", protocol);
+        error = KIO::ERR_CANNOT_LAUNCH_PROCESS;
+        delete slave;
+        return 0;
+    }
 
     if (forkSlaves() == 1) {
         QString _name = KProtocolInfo::exec(protocol);
@@ -475,13 +486,17 @@ Slave *Slave::createSlave(const QString &protocol, const QUrl &url, int &error,
             return 0;
         }
 
-        const QStringList args = QStringList() << lib_path << protocol << "" << slaveAddress.toString();
+        const QStringList args = QStringList() << lib_path << protocol << QLatin1String("") << slaveAddress.toString();
         //qDebug() << "kioslave" << ", " << lib_path << ", " << protocol << ", " << QString() << ", " << slaveAddress;
 
-        const QLatin1String libExecDir(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5);
-        const QString kioslaveExecutable = QStandardPaths::findExecutable("kioslave", {libExecDir});
+        // search paths
+        const QStringList searchPaths = QStringList()
+            << QCoreApplication::applicationDirPath() // then look where our application binary is located
+            << QLibraryInfo::location(QLibraryInfo::LibraryExecutablesPath) // look where libexec path is (can be set in qt.conf)
+            << QFile::decodeName(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5); // look at our installation location
+        const QString kioslaveExecutable = QStandardPaths::findExecutable(QStringLiteral("kioslave"), searchPaths);
         if (kioslaveExecutable.isEmpty()) {
-            error_text = i18n("Can not find 'kioslave' executable at '%1'", libExecDir);
+            error_text = i18n("Can not find 'kioslave' executable at '%1'", searchPaths.join(QStringLiteral(", ")));
             error = KIO::ERR_CANNOT_LAUNCH_PROCESS;
             delete slave;
             return 0;
@@ -516,9 +531,14 @@ Slave *Slave::holdSlave(const QString &protocol, const QUrl &url)
 {
     //qDebug() << "holdSlave" << protocol << "for" << url;
     // Firstly take into account all special slaves
-    if (protocol == "data") {
+    if (protocol == QLatin1String("data")) {
         return 0;
     }
+
+    if (forkSlaves()) {
+        return 0;
+    }
+
     Slave *slave = new Slave(protocol);
     QUrl slaveAddress = slave->d_func()->slaveconnserver->address();
     QDBusReply<int> reply = klauncher()->requestHoldSlave(url.toString(), slaveAddress.toString());
