@@ -32,7 +32,7 @@ KCookiesMain::KCookiesMain (QWidget* parent, const QVariantList&)
     management = 0;
     bool managerOK = true;
 
-    QDBusInterface kded (QStringLiteral("org.kde.kded5"), QStringLiteral("/kded"), QStringLiteral("org.kde.kded5"));
+    QDBusInterface kded (QStringLiteral("org.kde.kcookiejar5"), QStringLiteral("/kded"), QStringLiteral("org.kde.kcookiejar5"));
     QDBusReply<bool> reply = kded.call (QStringLiteral("loadModule"), QStringLiteral ("kcookiejar"));
 
     if (!reply.isValid()) {
