@@ -38,6 +38,7 @@
 
 class KUrlDragPushButton : public QPushButton
 {
+    Q_OBJECT
 public:
     KUrlDragPushButton(QWidget *parent)
         : QPushButton(parent)
@@ -225,7 +226,7 @@ public:
             int sep = it->indexOf('|');
             QString globs = it->left(sep);
             QString desc  = it->mid(sep + 1);
-            *it = QStringLiteral("%1 (%2)").arg(desc).arg(globs);
+            *it = QStringLiteral("%1 (%2)").arg(desc, globs);
         }
 
         return qFilters;
@@ -308,7 +309,7 @@ void KUrlRequester::KUrlRequesterPrivate::init()
         edit->setClearButtonShown(true);
     }
 
-    QWidget *widget = combo ? (QWidget *) combo : (QWidget *) edit;
+    QWidget *widget = combo ? static_cast<QWidget *>(combo) : static_cast<QWidget *>(edit);
 
     QHBoxLayout *topLayout = new QHBoxLayout(m_parent);
     topLayout->setMargin(0);
@@ -634,3 +635,4 @@ KUrlComboRequester::KUrlComboRequester(QWidget *parent)
 }
 
 #include "moc_kurlrequester.cpp"
+#include "kurlrequester.moc"
